==> cdw_0.3.1.orig.tar.gz: cdw-0.3.1/src/help.c <==
/* cdw
 * Copyright (C) 2002 Varkonyi Balazs
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <stdio.h>
#include <unistd.h>

#include <ncursesw/ncurses.h>
#include <ncursesw/menu.h>
#include <ncursesw/form.h>

#include <fcntl.h>
#include <nl_types.h>
#include <libintl.h>
#include "options.h"
#include "gettext.h"
#include "config.h"

WINDOW *help;
extern WINDOW *mainwin;

void show_help_main()
{
    int c;
    help=newwin(20,60,(LINES-20)/2,(COLS-60)/2);
    wbkgd(help, COLOR_PAIR(2));
    werase(help);
    box(help,0,0);
    keypad(help, TRUE);
    mvwaddch(help, 0, 2, ACS_RTEE);
    mvwprintw(help, 0, 3, " %s ", _("Help"));
    waddch(help, ACS_LTEE);    
    mvwprintw(help, 19, 2, "( %s )", _("Press ESC to close window"));
    mvwprintw(help, 2, 2, "%s", _("F1  - Show help"));
    mvwprintw(help, 3, 2, "%s", _("F2  - CD label window"));
    mvwprintw(help, 4, 2, "%s", _("F3  - Edit cdrecord parameters"));
    mvwprintw(help, 5, 2, "%s", _("F4  - Select CD size"));
    mvwprintw(help, 6, 2, "%s", _("F5  - View last log"));
    mvwprintw(help, 7, 2, "%s", _("F6  - Information about raw disk material"));
    mvwprintw(help, 8, 2, "%s", _("F10 - View the GPL"));
    mvwprintw(help, 9, 2, "%s", _("E   - Eject tray of CD-RW"));
    mvwprintw(help, 10, 2, "%s", _("C   - Disk catalog"));
    mvwprintw(help, 11, 2, "%s", _("A   - Add disk into Disk catalog"));
    mvwprintw(help, 12, 2, "%s", _("G   - Grab audio CD"));
    mvwprintw(help, 13, 2, "%s", _("Q   - Quit"));
    wrefresh(help);
    while (c!=27) {
	c=wgetch(help);
    }
    delwin(help);
}

void show_help_cddb()
{
    int c;
    help=newwin(20,60,(LINES-20)/2,(COLS-60)/2);
    wbkgd(help, COLOR_PAIR(2));
    werase(help);
    box(help,0,0);
    keypad(help, TRUE);
    mvwaddch(help, 0, 2, ACS_RTEE);
    mvwprintw(help, 0, 3, " %s ", _("Help"));
    waddch(help, ACS_LTEE);    
    mvwprintw(help, 19, 2, "( %s )", _("Press ESC to close window"));
    mvwprintw(help, 2, 2, "%s", _("->     - Step into catalogized files window"));
    mvwprintw(help, 3, 2, "%s", _("<-     - Step into menu window"));
    mvwprintw(help, 4, 2, "%s", _("ENTER  - Change category or disk or directory"));
    mvwprintw(help, 5, 2, "%s", _("BSPACE"));
    mvwprintw(help, 6, 2, "%s", _("/      - Move one level up"));
    mvwprintw(help, 7, 2, "%s", _("DEL    - Delete category or disk"));
    mvwprintw(help, 8, 2, "%s", _("A      - Add disk into catalog"));
    mvwprintw(help, 9, 2, "%s", _("S      - Show all disks"));
    mvwprintw(help,10, 2, "%s", _("Q      - Quit Disk catalog"));

    wrefresh(help);
    while (c!=27) {
	c=wgetch(help);
    }
    delwin(help);
}





void display_tooltip(int item)
{
	switch(item) {
		case 0:
			mvwprintw(mainwin, LINES - 4, 3, "Select files to be written to disc   ");
			mvwprintw(mainwin, LINES - 3, 3, "UP/DOWN arrows to move, Space to select files, Escape to finish   ");
			break;
		case 1:
			mvwprintw(mainwin, LINES - 4, 3, "Deselect files from list             ");
			mvwprintw(mainwin, LINES - 3, 3, "UP/DOWN arrows to move, Delete to deselect files, Escape to finish");
			break;
		case 2:
			mvwprintw(mainwin, LINES - 4, 3, "Create iso image using selected files");
			mvwprintw(mainwin, LINES - 3, 3, "Create on your hard disc iso file suitable for writing to CD      ");
			break;
		case 3:
			mvwprintw(mainwin, LINES - 4, 3, "Write data to disc                   ");
			mvwprintw(mainwin, LINES - 3, 3, "Write selected files or iso file to optical disc                  ");
			break;

		case 4:
			mvwprintw(mainwin, LINES - 4, 3, "Blank rewritable optical disc        ");
			mvwprintw(mainwin, LINES - 3, 3, "Erase content of optical disc - you can choose method             ");
			break;
		case 5:
			mvwprintw(mainwin, LINES - 4, 3, "Edit options                         ");
			mvwprintw(mainwin, LINES - 3, 3, "Edit cdw options like speed of recording or multiple CD sessions  ");
			break;
		case 6:
			mvwprintw(mainwin, LINES - 4, 3, "Close program                        ");
			mvwprintw(mainwin, LINES - 3, 3, "Close this program, return to your command line session           ");
			break;
		default:
			mvwprintw(mainwin, LINES - 4, 3, "                                     ");
			mvwprintw(mainwin, LINES - 3, 3, "                                                                  ");
			break;
	}

	return;
}

==> cdw_0.3.2.orig.tar.gz: cdw-0.3.2/src/help.c <==
/* cdw
 * Copyright (C) 2002 Varkonyi Balazs
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <stdio.h>
#include <unistd.h>

#include <ncursesw/ncurses.h>
#include <ncursesw/menu.h>
#include <ncursesw/form.h>

#include <fcntl.h>
#include <nl_types.h>
#include <libintl.h>
#include "options.h"
#include "gettext.h"
#include "config.h"

WINDOW *help;
extern WINDOW *mainwin;

void show_help_main()
{
    int c;
    help=newwin(20,60,(LINES-20)/2,(COLS-60)/2);
    wbkgd(help, COLOR_PAIR(2));
    werase(help);
    box(help,0,0);
    keypad(help, TRUE);
    mvwaddch(help, 0, 2, ACS_RTEE);
    mvwprintw(help, 0, 3, " %s ", _("Help"));
    waddch(help, ACS_LTEE);    
    mvwprintw(help, 19, 2, "( %s )", _("Press ESC to close window"));
    mvwprintw(help, 2, 2, "%s", _("F1  - Show help"));
    mvwprintw(help, 3, 2, "%s", _("F2  - CD label window"));
    mvwprintw(help, 4, 2, "%s", _("F3  - Edit cdrecord parameters"));
    mvwprintw(help, 5, 2, "%s", _("F4  - Select CD size"));
    mvwprintw(help, 6, 2, "%s", _("F5  - View last log"));
    mvwprintw(help, 7, 2, "%s", _("F6  - Information about raw disk material"));
    mvwprintw(help, 8, 2, "%s", _("F10 - View the GPL"));
    mvwprintw(help, 9, 2, "%s", _("E   - Eject tray of CD-RW"));
    mvwprintw(help, 10, 2, "%s", _("C   - Disk catalog"));
    mvwprintw(help, 11, 2, "%s", _("A   - Add disk into Disk catalog"));
    mvwprintw(help, 12, 2, "%s", _("G   - Grab audio CD"));
    mvwprintw(help, 13, 2, "%s", _("Q   - Quit"));
    wrefresh(help);
    while (c!=27) {
	c=wgetch(help);
    }
    delwin(help);
}

void show_help_cddb()
{
    int c;
    help=newwin(20,60,(LINES-20)/2,(COLS-60)/2);
    wbkgd(help, COLOR_PAIR(2));
    werase(help);
    box(help,0,0);
    keypad(help, TRUE);
    mvwaddch(help, 0, 2, ACS_RTEE);
    mvwprintw(help, 0, 3, " %s ", _("Help"));
    waddch(help, ACS_LTEE);    
    mvwprintw(help, 19, 2, "( %s )", _("Press ESC to close window"));
    mvwprintw(help, 2, 2, "%s", _("->     - Step into catalogized files window"));
    mvwprintw(help, 3, 2, "%s", _("<-     - Step into menu window"));
    mvwprintw(help, 4, 2, "%s", _("ENTER  - Change category or disk or directory"));
    mvwprintw(help, 5, 2, "%s", _("BSPACE"));
    mvwprintw(help, 6, 2, "%s", _("/      - Move one level up"));
    mvwprintw(help, 7, 2, "%s", _("DEL    - Delete category or disk"));
    mvwprintw(help, 8, 2, "%s", _("A      - Add disk into catalog"));
    mvwprintw(help, 9, 2, "%s", _("S      - Show all disks"));
    mvwprintw(help,10, 2, "%s", _("Q      - Quit Disk catalog"));

    wrefresh(help);
    while (c!=27) {
	c=wgetch(help);
    }
    delwin(help);
}





void display_tooltip(int item)
{
	switch(item) {
		case 0:
			mvwprintw(mainwin, LINES - 4, 3, _("Select files to be written to disc   "));
			mvwprintw(mainwin, LINES - 3, 3, _("UP/DOWN arrows to move, Space to select files, Escape to finish   "));
			break;
		case 1:
			mvwprintw(mainwin, LINES - 4, 3, _("Deselect files from list             "));
			mvwprintw(mainwin, LINES - 3, 3, _("UP/DOWN arrows to move, Delete to deselect files, Escape to finish"));
			break;
		case 2:
			mvwprintw(mainwin, LINES - 4, 3, _("Create iso image using selected files"));
			mvwprintw(mainwin, LINES - 3, 3, _("Create on your hard disc iso file suitable for writing to CD      "));
			break;
		case 3:
			mvwprintw(mainwin, LINES - 4, 3, _("Write data to disc                   "));
			mvwprintw(mainwin, LINES - 3, 3, _("Write selected files or iso file to optical disc                  "));
			break;

		case 4:
			mvwprintw(mainwin, LINES - 4, 3, _("Blank rewritable optical disc        "));
			mvwprintw(mainwin, LINES - 3, 3, _("Erase content of optical disc - you can choose method             "));
			break;
		case 5:
			mvwprintw(mainwin, LINES - 4, 3, _("Edit options                         "));
			mvwprintw(mainwin, LINES - 3, 3, _("Edit cdw options like speed of recording or multiple CD sessions  "));
			break;
		case 6:
			mvwprintw(mainwin, LINES - 4, 3, _("Close program                        "));
			mvwprintw(mainwin, LINES - 3, 3, _("Close this program, return to your command line session           "));
			break;
		default:
			mvwprintw(mainwin, LINES - 4, 3, "                                     ");
			mvwprintw(mainwin, LINES - 3, 3, "                                                                  ");
			break;
	}

	return;
}
